#
# spec file for package cdrtools
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cdrtools
Version:        3.02~a09
Release:        lp150.2.11
%define rver	3.02a09
Summary:        Tools for recording CD/DVD/BluRay media
License:        CDDL-1.0 and GPL-2.0 and GPL-2.0+ and BSD-2-Clause and BSD-3-Clause and HPND and ISC
Group:          Productivity/Multimedia/CD/Record
Url:            http://cdrtools.sourceforge.net/private/cdrecord.html

Source:         http://downloads.sf.net/cdrtools/cdrtools-%rver.tar.bz2
Source1:        cdrecord.easy
Source2:        cdrecord.secure
Source3:        cdrecord.paranoid
Source4:        cdda2wav.easy
Source5:        cdda2wav.secure
Source6:        cdda2wav.paranoid
Source7:        pre_checkin.sh
Patch1:         gcc48wa.diff
# Honor https://en.opensuse.org/openSUSE:Packaging_Patches_guidelines#Upstream_policy
# and submit patches upstream FIRST (cc to the bspkg maintainer perhaps).
Patch10:        fix_chrp_boot.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  libcap-devel
BuildRequires:  libscg-devel
BuildRequires:  libschily-devel >= %version
%if 0%{?suse_version} >= 1220
BuildRequires:  makedepend
%else
# makedepend was formerly included in xorg-x11-util-devel
BuildRequires:  xorg-x11-util-devel
%endif
# Requiring version-release is necessary for this rpm to pull in the latest cdrtools.
Requires:       cdda2wav = %version-%release
Requires:       cdrecord = %version-%release
Requires:       mkisofs = %version-%release
Provides:       schily-cdrtools = %version
Obsoletes:      schily-cdrtools < %version
Conflicts:      cdrkit-cdrtools-compat

# 0: completely disable caps in this build
%define with_caps 0
# 0: permission definitions provided through the "permissions" openSUSE package
# 1: provide permission.d files ourselves
%define standalone_permissions 0
%if 0%{?with_caps}
%define caps_cdda2wav %caps(cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_sys_rawio=ep)
%define caps_cdrecord %caps(cap_sys_resource,cap_dac_override,cap_sys_admin,cap_sys_nice,cap_net_bind_service,cap_ipc_lock,cap_sys_rawio=ep)
%define caps_readcd   %caps(cap_dac_override,cap_sys_admin,cap_net_bind_service,cap_sys_rawio=ep)
%else
%define caps_cdda2wav %nil
%define caps_cdrecord %nil
%define caps_readcd   %nil
%endif

%description
Cdrtools is a set of command line programs for writing to
CD/DVD/BluRay media. It will install the original cdrtools binaries.
This is the original version from Joerg Schilling. Built from clean
sources without patches.

%package -n btcflash
Summary:        Firmware flash utility for BTC DRW1008 DVD±RW recorder
License:        CDDL-1.0
Group:          Hardware/Other

%description -n btcflash
Btcflash is used to read update the Firmware for a BTC DRW1008
DVD+/-RW recorder. Be very careful when writing firmware as this
program does not check for the correctness of the target device.
Build from clean sources without patches.

%package -n cdda2wav
Summary:        A CD Digital Audio Extraction tool
License:        CDDL-1.0
Group:          Productivity/Multimedia/CD/Grabbers
Requires(post): permissions

%description -n cdda2wav
cdda2wav can retrieve CDDA audio tracks from CDROM drives that are
capable of reading audio data digitally to the host via SCSI.

%package -n cdrecord
Summary:        A CD/DVD/BD recording program
License:        CDDL-1.0
Group:          Productivity/Multimedia/CD/Record
Requires(post): permissions

%description -n cdrecord
cdrecord is a program to record data or audio Compact Discs on an
Orange Book CD recorder, to write DVD media on a DVD recorder or to
write BluRay media on a BluRay recorder.

%package -n mkisofs
Summary:        A program to generate an ISO-9660/Joliet/HFS/UDF hybrid filesystem
License:        GPL-2.0
Group:          Productivity/Multimedia/CD/Record
Requires:       zisofs-tools

%description -n mkisofs
mkisofs is effectively a pre-mastering program to generate an
ISO-9660/JOLIET/HFS/UDF hybrid filesystem.

%prep
%setup -qn cdrtools-3.02
%patch -P 1 -p1
%patch10 -p1

%build
#
# We want to prefer the files from /usr/include, but gcc blatantly ignores
# -I arguments pointing to system paths. (CFLAGS=-I%_includedir is therefore
# out of the question.)
#
rm -Rf include/schily/*.h libscg/scg/*.h
cp -a "%_includedir/schily"/*.h include/schily/
cp -a "%_includedir/scg"/*.h libscg/scg/

#
# (this is a noninteractive build; nobody will read the warnings
# or care about the pause, so use GMAKE_NOWARN.)
#
# To enable verbosity, use with CC=cc LDCC=cc DYNLD=cc.
#
# Note that specifying -fPIE/-pie here conflicts with the generation
# of shared objects, which is why we build those separately
# in schily-libs.spec instead.
#
# Not fully parallel safe, so stick to default.
#
gmake GMAKE_NOWARN=true RUNPATH="" \
	CCCC=cc LDCC="cc -L%_libdir" DYNLD=cc \
	COPTX="%optflags -fno-strict-aliasing -fno-omit-frame-pointer \
		-fPIE -ggdb -finput-charset=ISO-8859-1" \
	LDOPTX="-pie -Wl,-pie -ggdb" RUNPATH=""

%install
b="%buildroot"
# D'oh… not parallel safe
gmake GMAKE_NOWARN=true RUNPATH="" \
	DESTDIR="$b" INS_BASE="%_prefix" install -j1

# Devel files not used and/or already provided by libschily-devel, libscg-devel
rm -Rf "$b/%_includedir" "$b/%_prefix/lib"/*.a "$b/%_prefix/lib/profiled" \
	"$b/%_mandir/man5"/makefiles.5* \
	"$b/%_mandir/man5"/makerules.5* \
	"$b/%_mandir/man3"/*.3*

%if %standalone_permissions
mkdir -p "$b/%_sysconfdir/permissions.d/"
install -pm 0644 "%_sourcedir"/{cdrecord,cdda2wav}.{easy,secure,paranoid} \
	"$b/%_sysconfdir/permissions.d/"
%endif

#
# pushd "$b/%_prefix"
# test -d "./%_lib" || mv -T ./lib "./%_lib"
# popd


# Needed by cdda2wav (see cdda2wav.c)
ln -sf cdda2wav "$b/%_bindir/list_audio_tracks"

# Remove documentation (will be added in %_datadir/doc/packages/*)
rm -Rf "$b/%_datadir/doc"/*

# Install additional programs
install -pm 0755 cdda2wav/{cdda2mp3.new,inf2cdtext.pl,pitchplay,readmult,tracknames.pl} \
	mkisofs/hdisk.pl "$b/%_bindir/"

# Fix perl path
perl -pi -e 's#/usr/local/bin/perl#%_bindir/perl#g' "$b/%_bindir/tracknames.pl"

# Rename in order to not conflict with mkisofs/README in rpm doc section
mv mkisofs/diag/README mkisofs/diag/README.diag

%fdupes -s %buildroot/%_prefix

%if 0%{?suse_version} >= 1120
%verifyscript -n cdrecord
%{verify_permissions -e %_bindir/cdrecord -e %_bindir/readcd}

%verifyscript -n cdda2wav
%{verify_permissions -e %_bindir/cdda2wav}

%endif

%post -n cdrecord
%if 0%{?set_permissions:1} > 0
%set_permissions %_bindir/cdrecord %_bindir/readcd
%else
%run_permissions
%endif
true

%post -n cdda2wav
%if 0%{?set_permissions:1} > 0
%set_permissions %_bindir/cdda2wav
%else
%run_permissions
%endif
true

%files
%defattr(-,root,root)
%doc ABOUT AN* CDDL.Schily.txt COPYING Changelog Changelog.1 GPL-2.0.txt
%doc LGPL-2.1.txt README.linux-shm READMEs/README.linux

%files -n btcflash
%defattr(-,root,root)
%doc CDDL.Schily.txt COPYING
%_bindir/btcflash
%doc %_mandir/man1/btcflash.1%ext_man

%files -n cdda2wav
%defattr(-,root,root)
%doc CDDL.Schily.txt
%doc cdda2wav/Changelog cdda2wav/FAQ cdda2wav/Frontends cdda2wav/HOWTOUSE
%doc cdda2wav/NEEDED cdda2wav/README cdda2wav/THANKS cdda2wav/TODO
%doc cdda2wav/tracknames.txt
%doc libparanoia/README.paranoia
%_bindir/cdda2mp3
%_bindir/cdda2mp3.new
%_bindir/cdda2ogg
%if 0%{?suse_version} >= 1140
%attr(0755,root,root) %caps_cdda2wav %verify(not mode caps) %_bindir/cdda2wav
%else
%attr(0755,root,root) %caps_cdda2wav %verify(not mode) %_bindir/cdda2wav
%endif
%_bindir/inf2cdtext.pl
%_bindir/list_audio_tracks
%_bindir/pitchplay
%_bindir/readmult
%_bindir/tracknames.pl
%doc %_mandir/man1/cdda2mp3.1%ext_man
%doc %_mandir/man1/cdda2ogg.1%ext_man
%doc %_mandir/man1/cdda2wav.1%ext_man
%if %standalone_permissions
%config %_sysconfdir/permissions.d/cdda2wav.*
%endif

%files -n cdrecord
%defattr(-,root,root)
%doc CDDL.Schily.txt START
%doc cdrecord/COPYING cdrecord/README cdrecord/README.ATAPI
%doc cdrecord/README.DiskT@2 cdrecord/README.WORM cdrecord/README.audio
%doc cdrecord/README.cdplus cdrecord/README.cdrw cdrecord/README.cdtext
%doc cdrecord/README.clone cdrecord/README.copy cdrecord/README.multi
%doc cdrecord/README.parallel cdrecord/README.raw cdrecord/README.rscsi
%doc cdrecord/README.sony cdrecord/README.verify cdrecord/README.volmgt
%doc rscsi/default-rscsi.sample
%config %_sysconfdir/default/cdrecord
%config %_sysconfdir/default/rscsi
%if %standalone_permissions
%config %_sysconfdir/permissions.d/cdrecord.*
%endif
%if 0%{?suse_version} >= 1140
%verify(not mode caps) %caps_cdrecord %attr(0755,root,root) %_bindir/cdrecord
%verify(not mode caps) %caps_readcd %attr(0755,root,root) %_bindir/readcd
%else
%verify(not mode) %caps_cdrecord %attr(0755,root,root) %_bindir/cdrecord
%verify(not mode) %caps_readcd %attr(0755,root,root) %_bindir/readcd
%endif
%_bindir/scgcheck
%_bindir/scgskeleton
%_sbindir/rscsi
%doc %_mandir/man1/cdrecord.1%ext_man
%doc %_mandir/man1/readcd.1%ext_man
%doc %_mandir/man1/rscsi.1%ext_man
%doc %_mandir/man1/scgcheck.1%ext_man
%doc %_mandir/man1/scgskeleton.1%ext_man

%files -n mkisofs
%defattr(-,root,root)
%doc CDDL.Schily.txt GPL-2.0.txt
%doc mkisofs/COPYING mkisofs/ChangeLog mkisofs/ChangeLog.mkhybrid
%doc mkisofs/README mkisofs/README.* mkisofs/RELEASE mkisofs/TODO
%doc mkisofs/diag/README.diag
%_bindir/devdump
%_bindir/hdisk.pl
%_bindir/isodebug
%_bindir/isodump
%_bindir/isoinfo
%_bindir/isovfy
%_bindir/mkhybrid
%_bindir/mkisofs
# Hardcoded paths in executable. Needs fixing. This is in /usr/lib/siconv instead for now
# %%_libdir/siconv/
%_prefix/lib/siconv/
%doc %_mandir/man8/devdump.8%ext_man
%doc %_mandir/man8/isodebug.8%ext_man
%doc %_mandir/man8/isodump.8%ext_man
%doc %_mandir/man8/isoinfo.8%ext_man
%doc %_mandir/man8/isovfy.8%ext_man
%doc %_mandir/man8/mkhybrid.8%ext_man
%doc %_mandir/man8/mkisofs.8%ext_man

%changelog
* Mon Mar 12 2018 adam.majer@suse.de
- fix_chrp_boot.patch: chrp-boot option doesn't take any parameters
  but seems to require one that it doesn't use. Fix it uses no
  parameters. (bnc#1084893)
- Always install to /usr/lib/siconv since otherwise mkisofs doesn't
  find charsets. Needs to be fixed properly later. (bnc#1084892)
* Thu Dec 14 2017 jengelh@inai.de
- Update to new upstream release 3.02~a09
  * Cdda2wav now works around a Linux glibc bug that causes stderr
    to be illegally buffered.
  * `cdda2wav -vall` no longer clobbers out-fd= to become stdin
    when compiled in 64 bit mode.
* Thu May 11 2017 adaugherity@tamu.edu
- Fix build on older distros (e.g. SLE11) -- no caps support in RPM
- Remove build dependency on mmv (not present on SLE, and its usage
  is easily replaced with a small shell script).
- Fix build on older distros (makedepend)
* Wed Dec 28 2016 jengelh@inai.de
- Update to new upstream release 3.02~a07
  * mkisofs: deduplication for files)
* Thu Jan 28 2016 jengelh@inai.de
- Update to new upstream release 3.02~a06
  * libscg: fixed a copy/paste problem in the Linux transport that
  could cause libscg to assume a timeout when no timeout occurred.
  * libscg: add a new generic option interface.
  * libscg: New option "ignore-resid" to work around a Linux kernel
  problem.
  * mkisofs: better warning messages for rotten directories when in
  multi-session mode.
* Thu Dec 31 2015 jengelh@inai.de
- Update to new upstream release 3.02~a05
  * mkisofs now tries to be more immune against rotten iso images
  when in multi session mode.
  * mkisofs no longer tries to access a string past the null byte
  when dealing with Joliet.
  * mkisofs fixed a bug related to sorting with multi extent files
  (greater than 4 GB).
* Wed Dec 16 2015 jengelh@inai.de
- Update to new upstream release 3.02~a04
  * Support for DVD-Audio was added to mkisofs.
  * Several bug fixes in mkisofs and mkisofs/diag/* programs to make
  them more robust against rotten ISO images.
* Wed Dec  2 2015 jengelh@inai.de
- Update to new upstream release 3.02~a03
  * isoinfo no longer eats up all memory when an ISO image
  with a directory loop is specified.
* Fri Nov 20 2015 jengelh@inai.de
- Update to new upstream release 3.02~a02
  * Many smaller "isoinfo" enhancements including support for
  relocated directories.
* Fri Nov  6 2015 jengelh@inai.de
- Update to new upstream release 3.02~a01
  * libparanoia: work around a bug that resulted from uninitalized
  statistics data for C2 checks.
  * cdda2wav now supports sound output on Linux again.
* Sun Aug 30 2015 jengelh@inai.de
- Update to new upstream release 3.01
  * Final version
* Wed Aug  5 2015 jengelh@inai.de
- Update to new upstream release 3.01~a31
  * Added compile support for Win-10 using non-automake-aware make
  implementations. Add some workarounds for MinGW32 compilation.
* Wed Jul  8 2015 jengelh@inai.de
- Update to new upstream release 3.01~a30
  * Added a workaround (with autoconf) for a Cygwin bug with
  [#]pragma weak.
* Thu Jun  4 2015 jengelh@inai.de
- Update to new upstream release 3.01~a29
  * (Several changes for better Haiku compatibility.)
  * Some code fixes include results from automated tests.
* Wed Mar 25 2015 jengelh@inai.de
- Update to new upstream release 3.01~a28
  * Build system changes only: manpages are installed just once
* Thu Feb 19 2015 jengelh@inai.de
- Update to new upstream release 3.01~a27
  * dlopen emulation for certain platforms
* Fri Jan  9 2015 jengelh@inai.de
- Update to new upstream release 3.01~a26
  * Add the HELIOS UNICODE mapping code. This needs to be done at
  UCS-2 level for Joliet and UDF (instead of UTF-8) and only for
  Rock Ridge (in case of a UTF-8 based target locale) using UTF-8
  based translations.
  * Make the Apple extensions work again with "mkisofs -find"
* Thu Dec  4 2014 meissner@suse.com
- run permission handling code unconditionally. bnc#899718
* Sat Nov 29 2014 jengelh@inai.de
- Update to new upstream release 3.01~a25
  * Precursory work for localization
- Run spec-beautifier for spec files
- Reenable missing capability support [bnc#899718]
* Mon Sep 22 2014 jengelh@inai.de
- Update package metadata: new upstream URLs
- Remove untracked old changes file
* Wed May  7 2014 jengelh@inai.de
- Update to new upstream release 3.01~a24
  * isoinfo now allows the user to extract all files from an ISO
  image based on the built-in find(1) command. This works even for
  milti-extent files (files > 4 GB).
  * Some enhancements for the libschily *at() function emulations
  have been added.
* Wed Mar  5 2014 jengelh@inai.de
- Update to new upstream release 3.01~a23
  * Cdrecord now prints timediffs also in hours:minutes:seconds.
  * Cdda2wav no longer includes "c2check" in the "proof" paranoia
  option to avoid a firmware bug in a TSSTcorp drive.
  * Mkisofs has slightly-reduced CPU time requirements.
  * A problem in isoinfo has been fixed; it did not always print
  timestamps in `-find -ls` mode.
* Tue Jan 21 2014 jengelh@inai.de
- Update to new upstream release 3.01~a22
  * mkisofs includes a new option, -legacy, that allows it to
  reenable the short options -H/-L/-P; these have been disabled in
  2006 for compatibility with scripts that have not been updated
  during the past 10 years.
  * libsiconv now only tries to open a file when the argument
  includes a slash in its name.
  * libschily::printf() now includes support for %%n$ argument
  reordering for the first 30 arguments.
- Drop ppc64le.patch (merged upstream)
* Mon Jan  6 2014 jengelh@inai.de
- Update to new upstream release 3.01~a21
  * This release adds some workarounds for compiling with MinGW. New
  functions xcomerr(), xcomerrno(), fxcomerr(), and fxcomerrno() in
  libschily. A bug in libschily/format.c that caused %%.*s to be
  printed incorrectly has been fixed. Some bugs in the mkisofs man
  page have been fixed.
* Thu Jan  2 2014 dvaleev@suse.com
- enable ppc64le architecture (ppc64le.patch)
* Thu Dec 26 2013 jengelh@inai.de
- Update to new upstream release 3.01~a20
  * libparanoia and cdda2wav have been enhanced to give much better
  results with slightly bad media and new hardware.
- Enable symbol versions
* Tue Dec  3 2013 jengelh@inai.de
- Update to new upstream release 3.01~a19
  * This release added different fine-grained privilege handling that
  keeps root privileges in cases where cdrtools have been called by
  a privileged program.
  * Libfind now supports "event port" type files.
  * Emulations for *at() functions have been added to libschily.
- Mark the mkisofs program (combined work) as GPL-2.0 due to
  some GPL2-only sources (mkisofs/inode.c).
* Thu Nov 14 2013 jengelh@inai.de
- Add gcc48wa.diff to work around broken gcc-4.8 behavior
* Tue Oct 15 2013 jengelh@inai.de
- Update to new upstream release 3.01a18
  * This release fixes a copy+paste bug in the Linux support code for
  fine-grained privileges.
  * Libfind no longer leaks filedescriptors with -empty.
* Fri Oct  4 2013 jengelh@inai.de
- Update to new upstream release 3.01a17
  * Automatic support has been added for ARMv5 and ARMv6.
* Thu Jul 11 2013 zawel1@gmail.com
- Update to 3.01a16
  * libparanoia: memset() call in i_silence_match() now uses the
    correct size instead of sizeof (avec)
  * libparanoia: Use dynamic arrays instead of alloca()/malloc()
    if available
* Thu Jun  6 2013 jengelh@inai.de
- Update BuildRequires, add License: fields, use %%optflags, update
  descriptions and wrap at 70 cols
- Remove unused static libraries and dissolve devel subpackage
  (now provided by libschily-devel, libscg-devel)
* Mon Jun  3 2013 jengelh@inai.de
- Update to new upstream release 3.01~a15
  * This release warns about lack of fine-grained permissions
- Temporarily deactivate extra permissions for factory submission
  while permissions package is not updated
* Tue May 14 2013 jengelh@inai.de
- Add cdda2wav.{easy,paranoid,secure}. permissions.d entries need
  to be in the same package as the file they are describing, or we
  get errors during post-build verification.
- Use tildeversion; according to author, 3.01a14 sorts before 3.01
- Resync caps list from permissions.d files to .spec file
* Sun May  5 2013 meissner@suse.com
- actually fscaps are also managed by "permissions", leave the
  %%set_permissions calls in.
- reenabled the sample permission snippets for testing.
* Sat May  4 2013 jengelh@inai.de
- Do not run set_permissions when fscaps are in use
* Sat May  4 2013 meissner@suse.com
- commented out the setuid root equivalent capabilities, cap_sys_admin
  and cap_dac_override. (bnc#550021)
- commented out unnecessary and also dangerous cap_net_bind_service
  (bnc#550021)
- add correct permission handling also for readcd and cdda2wav
* Fri May  3 2013 jengelh@inai.de
- Linux fscaps support in the RPM package (bnc#550021)
* Fri May  3 2013 davejplater@gmail.com
- Commented out permissions.d files and
  ran spec cleaner.
* Mon Apr 22 2013 zawel1@gmail.com
- Update to 3.01a14
  * new autoconf tests for sys/capability.h and cap_*() functions
  from Linux -lcap
  * trying to support suid-root-less installation of cdrecord on Linux.
  NOTE: You need "file caps" support built into your Linux installation.
  * include/schily/stat.h now contains macros to set the nanoseconds
  in timestamps in a OS independent way
  * mkisofs now identifies itdelf by default (inside the APPID string)
  as being UDF capable.
  * mkisofs now supports additional file types with UDF: named pipes,
  sockets, character devices, block devices
  * mkisofs now supports all three UNIX times with microsecond granularity
    in UDF
  * mkisofs now sets correct user/group/permission for symlinks in UDF
  * mkisofs now supports setuid, setgid, sticky bits in UDF
* Tue Apr  2 2013 jengelh@inai.de
- Dissolve Obsoletes cycle between cdrkit (source package "wodim")
  and cdrtools. Conflict tags have been submitted to cdrkit.
* Tue Feb 12 2013 zawel1@gmail.com
- Update to 3.01a12
  * mkisofs: mkisofs now reserves more space for the file names
    to avoid a path buffer overrun
  * mkisofs: fixed a bug that caused to put more than one UDF
    direcory entry for a file in case that the file is a ISO-0660
    multi-segment file.
  * mkisofs: fixed a bug that caused the wrong start sector address
    to be used for UDF in case that the file is a ISO-9660
    multi-segment file and the -sort option was used.
  * libschily: libschily::fexecv() now allows to use the parameter
    "ac" with the value -1 to indicate that the arg count is to be
    determined by the NULL pointer at the end of the arg list
  * new include files include/schily/err_*.h are used to
    encapsulate #error CPP statements that would otherwise always
    prevent compilation with K&R compilers
  * mkisofs: new option -ignore-error alows to continue on some
    errors
  * mkisofs: Avoid a 32 bit integer overflow while computing sector
    addresses for Rock Ridge CE entries
* Mon Oct  1 2012 zawel1@gmail.com
- Update to 3.01a08
  * introduce a dependency for man page subdirectories to allow
  syncing parallel make calls.
  * libschily: getperm.c now correctly supports umask +w
  * libscg & cdrecord: struct scsi_inquiry is now using a union
  around the vendor ID strings in order to avoid incorrect buffer
  overflow warnings from GCC-4.x
  * mkisofs: while introducing the new option -modification-date,
  we did accidently remove the code to set up the creation date
  in te PVD. Now creation date again contains correct data.
* Tue Mar 27 2012 davejplater@gmail.com
- Update to version 3.01a07 Fixed non position independant build of
  cdrecord with "COPTX=-fPIE" and "LDOPTX=-pie -Wl,-pie"
* Mon Dec 26 2011 hnch@gmx.net
- Disabled parallel build.
* Mon Dec 26 2011 hnch@gmx.net
- Update to 3.01a06.
* Tue Jun  7 2011 davejplater@gmail.com
- Update to 3.01a05 via source service.
* Wed Apr  6 2011 davejplater@gmail.com
- Fixed provides, obsoletes and requires to stop cdrtools from
  requiring packages from wodim.
* Sat Apr  2 2011 asterios.dramis@gmail.com
- Updated to 3.00
- Spec file updates:
  * Changed the Name: entry to cdrtools and added cdrecord as a subpackage.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Summary: and %%description sections.
  * Removed meta package schily-cdrtools and used the main package for
    cdrkit-cdrtools-compat removal.
  * Added Conflicts: for cdda2wav and mkisofs (with icedax and genisoimage
    respectively).
  * Use smp_flags with make.
  * Updates in %%install section. Most important:
    [#] Remove installed documentation and install it manually in the %%files
    sections.
    [#] Install additional programs.
    [#] Don't run fdupes in /etc/permissions.d/ (some may want to have different
    contents in each file).
  * Updates in %%files sections.
  * Removed the %%changelog entries from the spec file.
* Sat Feb 12 2011 hnch@gmx.net
- A lot of cleanup fixes in the spec file, e.g. corrected paths,
  added debuginfo. Thanks to Křištof Želechovski for the patches.
* Fri Nov 26 2010 hnch@gmx.net
- Small fixes to satisfy rpmlint.
* Fri Nov 26 2010 hnch@gmx.net
- Updated to 3.01a01
* Wed Jun  2 2010 hnch@gmx.net
- Updated to final 3.00
* Thu Apr 15 2010 dmueller@suse.de
- fix requires(pre) -> requires(post)
* Fri Apr  9 2010 hnch@gmx.net
- Reinstalled Prerequisites as Requires(pre)
* Tue Apr  6 2010 hnch@gmx.net
- Updated to 2.01.01a77
* Tue Feb  2 2010 hnch@gmx.net
- Updated to 2.01.01a74
* Mon Jan 11 2010 hnch@gmx.net
- Updated to 2.01.01a72
* Tue Jan  5 2010 meissner@suse.de
- disable the permissions override
* Tue Dec 29 2009 hnch@gmx.net
- Updated to 2.01.01a70
* Tue Dec  1 2009 hnch@gmx.net
- Updated to 2.01.01a69
* Fri Nov 20 2009 hnch@gmx.net
- Updated to 2.01.01a68
* Wed Nov  4 2009 hnch@gmx.net
- removed /etc/permissions.d/ entries for readcd, rscsi and cdda2wav again
* Mon Nov  2 2009 hnch@gmx.net
- removed conflicting Provides: from schily-cdrtools package
* Mon Nov  2 2009 hnch@gmx.net
- Updated to a67
- added /etc/permissions.d/ entries for readcd, rscsi and cdda2wav as well
* Mon Oct 26 2009 hnch@gmx.net
- Once again permissions.d/ files, fixed spec file.
* Mon Oct 26 2009 hnch@gmx.net
- Fixed wrong naming of permissions.d/ files.
* Sun Oct 25 2009 meissner@suse.de
- import from henneodernich home repo
- removed up %%post illegal operation and instead drop in permission.d snippets
  4711 in easy mode, 0711 in secure and paranoid modes.
  added rpmlintrc to allow this temporarily
- removed unused obsoletes
- conflict with cdrkit-cdrtools-compat instead of obsoletes
- alsa-devel buildrequires
